@@ -284,6 +284,7 @@ class WKTTestCase(unittest.TestCase):
         self.assertEqual(p.x, 0.0)
         self.assertEqual(p.y, 1.0)
         self.assertEqual(p.to_wkt(), 'POINT (0.0 1.0)')
+        self.assertEqual(p.to_wkt(), p.wkt)
         self.assertEqual(str(p), 'POINT (0.0 1.0)')
         self.assertEqual(p.geom_type, 'Point')
 
@@ -420,6 +421,12 @@ class AsShapeTestCase(unittest.TestCase):
         self.assertRaises(NotImplementedError, geometry.as_shape, f)
 
 
+    def test_dict_asshape(self):
+        f = geometry.MultiLineString( [[[0.0, 0.0], [1.0, 2.0]]] )
+        s = geometry.as_shape(f.__geo_interface__)
+        self.assertEqual(f.__geo_interface__, s.__geo_interface__)
+
+
 
 def test_suite():
     suite = unittest.TestSuite()
